Daemon rucio-abacus-rse — Rucio 1.2 documentation

# Daemon rucio-abacus-rse

    usage: rucio-abacus-rse [-h] [--run-once] [--process PROCESS]
                            [--total-processes TOTAL_PROCESSES]
                            [--threads-per-process THREADS_PER_PROCESS]

## Named Arguments

`--run-once` | One iteration only Default: False
`--process` | Concurrency control: current processes number Default: 0
`--total-processes`
| Concurrency control: total number of processes Default: 1
`--threads-per-process`
| Concurrency control: total number of threads per process Default: 1